@@ -2,19 +2,17 @@
 #' 
 #' @description converts a dart file (read via \code{read.dart}) into an genlight object \code{\link{adegenet}}. Internal function called by gl.read.dart
 #' @param dart a dart object created via read.dart
-#' @param covfilename optional file in csv format with covariates for each individual (see details for explanation)
+#' @param ind.metafile optional file in csv format with covariates for each individual (see details for explanation)
+#' @param covfilename depreciated, use parameter ind.metafile
 #' @param probar show progress bar
 #' @return a genlight object is returned. Including all available slots are filled. loc.names, ind.names, pop, lat, lon (if provided via the covariate file)
 #' @details the covariate file needs to have very specific headings. First an heading called id. Here the ids have to match the ids in the dart object \code{colnames(dart[[4]])}. The following column headings are optional. pop: specifies the population membership of each individual. lat and lon specify spatial coordinates (perferable in decimal degrees WGS1984 format). Additional columns with individual covariates can be imported (e.g. age, gender).
-#' @examples
-#' \dontrun{
-#' dgl <- dart2genlight(dart, "covariates.csv")
-#' }
 
 
-dart2genlight <- function(dart, covfilename=NULL, probar = TRUE)
+dart2genlight <- function(dart, ind.metafile=NULL, covfilename=NULL, probar = TRUE)
  {
 
+if (is.null(ind.metafile)) {ind.metafile <- covfilename}
  
 #### out contains the dart data
 nind <- dart[["nind"]]
@@ -104,11 +102,11 @@ gout@other$loc.metrics <- df
 ####
 #additional covariates and long lat to the data file are stored in other
 
-if (!is.null(covfilename))
+if (!is.null(ind.metafile))
 {
-cat(paste("Try to add covariate file:", covfilename,".\n"))
+cat(paste("Try to add covariate file:", ind.metafile,".\n"))
 ###### population and individual file to link AAnumbers to populations...
-ind.cov <- read.csv(covfilename, header=T, stringsAsFactors=T)
+ind.cov <- read.csv(ind.metafile, header=T, stringsAsFactors=T)
 # is there an entry for every individual
 
 id.col = match( "id", names(ind.cov))
